@@ -6,6 +6,12 @@ use logic::{Environment, Error};
 #[pyclass(name = "Environment")]
 struct PyEnvironment {
     env: Environment,
+    #[pyo3(get)]
+    sorts: Vec<String>,
+    #[pyo3(get)]
+    functions: Vec<(String, Vec<String>, String)>,
+    #[pyo3(get)]
+    sequents: Vec<(Vec<(PyObject, PyObject)>, Vec<(PyObject, PyObject)>)>,
 }
 
 #[pymethods]
@@ -14,6 +20,9 @@ impl PyEnvironment {
     fn new() -> Self {
         PyEnvironment {
             env: Environment::new(),
+            sorts: Vec::new(),
+            functions: Vec::new(),
+            sequents: Vec::new(),
         }
     }
 
@@ -27,19 +36,23 @@ impl PyEnvironment {
         argument_type: Vec<&str>,
         result_type: &str,
     ) -> PyResult<()> {
-        self.env
-            .declare_function(name, argument_type, result_type)?;
+        match self.env.declare_function(name, argument_type, result_type)? {
+            (newsorts, (name, argument_type, result_type)) => {
+                self.sorts.extend(newsorts);
+                self.functions.push((name, argument_type, result_type));
+            }
+        }
         Ok(())
     }
 
-    fn declare_sequent(&mut self, s: &str) -> PyResult<()> {
-        self.env.declare_sequent(s)?;
+    fn declare_sequent(&mut self,  _py: Python, s: &str) -> PyResult<()> {
+        self.sequents.push(self.env.declare_sequent(_py, s)?);
         Ok(())
     }
 }
 
 #[pymodule]
-fn fol_embedding(_py: Python, m: &PyModule) -> PyResult<()> {
+fn _fol_embedding(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add_class::<PyEnvironment>()?;
     Ok(())
 }
@@ -58,22 +71,4 @@ impl std::convert::From<Error> for PyErr {
             Error::IllegalTerm(s) => PyValueError::new_err(format!("Illegal Term {}", s)),
         }
     }
-}
-
-#[cfg(test)]
-mod tests {
-    use crate::logic::Environment;
-
-    #[test]
-    fn simple_sequent() {
-        let mut e = Environment::new();
-        match e.declare_function("c", vec![], "A") {
-            Ok(_) => {}
-            Err(err) => panic!("Error"),
-        }
-        match e.declare_sequent("c = c => c = c") {
-            Ok(_) => {}
-            Err(err) => panic!("Error"),
-        }
-    }
-}
+}
\ No newline at end of file
